# Stroop

Show a text string in a chosen color. Optionally collect keyboard responses while the text is on screen.

## When To Use

- Simple Stroop-style text displays (color/word).

## Example

A colored word is displayed. In most variants, the participant is asked to name the color of the word. Here, we show a version where the participant has to decide weather color and word fit (are congruent) or not (are incongruent).

![Stroop Task](../../img/stimuli/stroop.png)